def 模块_更新内容查看():
    分隔符 = "-" * 100
    更新内容 = f"""
{分隔符}
版本号：1.0.172 ---- 2024年7月12日
新增命令：mysql_克隆表单_仅结构(连接对象,源表名,目标表名，#自动递增是否归重置>布尔型，可空<) -->返回一个布尔型：成功返回True，失败返回 False
新增命令：mysql_克隆表单_结构和数据(连接对象,源表名,目标表名)   -->返回一个布尔型：成功返回True，失败返回 False
新增命令：mysql_更新_字段名(连接对象,表名,新字段名列表)   -->返回一个布尔型：成功返回True，失败返回 False
新增命令：mysql_查询_表结构(连接对象,表名)  -->返回一个列表用于存储：结构信息，失败则返回空列表
新增命令：mysql_创建新表(连接对象,表名,结构信息)   -->返回一个布尔型：成功返回True，失败返回 False
{分隔符}
版本号：1.0.173 ---- 2024年7月12日
新增命令：模块_更新内容查看()    -->无需传递任何参数且没有返回值，默认打印每个版本更新的内容详情
{分隔符}
版本号：1.0.174 ---- 2024年7月13日
修复已知BUG
{分隔符}
版本号：1.0.175 ---- 2024年7月13日
修复命令：mysql_更新_字段名(连接对象,表名,新字段名列表)  字符集问题导致无法正常修改的情况
{分隔符}
版本号：1.0.176 ---- 2024年7月14日
新增命令：邮件IMAP_按日期和发件人搜索邮件(连接对象, 年(int), 月(int), 日(int), 发件人邮箱(str), 条件="SINCE")    -->最后的条件"SINCE"表示条件日期之后的，"BEFORE"表示取之前的
新增命令：邮件IMAP_按日期和主题搜索邮件(连接对象, 年(int), 月(int), 日(int), 主题(str), 条件="SINCE")    -->最后的条件"SINCE"表示条件日期之后的，"BEFORE"表示取之前的
{分隔符}
"""
    print(更新内容)
