from .邮件POP3_删除邮件 import 邮件POP3_删除邮件
from .邮件POP3_批量删除邮件 import 邮件POP3_批量删除邮件
from .邮件POP3_断开连接 import 邮件POP3_断开连接
from .邮件POP3_登录 import 邮件POP3_登录
from .邮件POP3_获取最新一封邮件 import 邮件POP3_获取最新一封邮件
from .邮件POP3_获取最新五封邮件 import 邮件POP3_获取最新五封邮件
from .邮件POP3_获取最新十封邮件 import 邮件POP3_获取最新十封邮件
from .邮件POP3_获取邮件内容 import 邮件POP3_获取邮件内容
from .邮件POP3_获取邮件数量 import 邮件POP3_获取邮件数量
from .邮件POP3_获取邮箱占用空间 import 邮件POP3_获取邮箱占用空间