from .文本_从中间往右取 import 文本_从中间往右取
from .文本_从中间往左取 import 文本_从中间往左取
from .文本_从右往左取 import 文本_从右往左取
from .文本_从左往右取 import 文本_从左往右取
from .文本_分割文本 import 文本_分割文本
from .文本_到大写 import 文本_到大写
from .文本_到小写 import 文本_到小写
from .文本_加密 import 文本_加密
from .文本_十六进制替换 import 文本_十六进制替换
from .文本_去除指定字符串_首次出现 import 文本_去除指定字符串_首次出现
from .文本_去除指定字符串_自定义位置 import 文本_去除指定字符串_自定义位置
from .文本_去除指定字符串_末次出现 import 文本_去除指定字符串_末次出现
from .文本_去除换行符 import 文本_去除换行符
from .文本_去除空格 import 文本_去除空格
from .文本_去除空格和换行符 import 文本_去除空格和换行符
from .文本_取出中间文本 import 文本_取出中间文本
from .文本_取出现次数 import 文本_取出现次数
from .文本_取右边 import 文本_取右边
from .文本_取左边 import 文本_取左边
from .文本_取指定变量文本行 import 文本_取指定变量文本行
from .文本_取文本所在行 import 文本_取文本所在行
from .文本_取文本指定次数出现的位置 import 文本_取文本指定次数出现的位置
from .文本_取文本最后出现的位置 import 文本_取文本最后出现的位置
from .文本_取文本首次出现的位置 import 文本_取文本首次出现的位置
from .文本_取行数 import 文本_取行数
from .文本_取长度 import 文本_取长度
from .文本_取随机字符 import 文本_取随机字符
from .文本_取随机范围数字 import 文本_取随机范围数字
from .文本_字符串替换 import 文本_字符串替换
from .文本_替换行内容 import 文本_替换行内容
from .文本_解密 import 文本_解密
from .文本_颠倒 import 文本_颠倒
from .文本区分_只取符号 import 文本区分_只取符号
from .文本区分_只取汉字 import 文本区分_只取汉字
from .文本区分_只取数字 import 文本区分_只取数字